Crate serde_bebop

Crate serde_bebop 

A Serde implementation of the Bebop protocol.

Structs

Deserializer
A Deserializer implementation for Bebop
Serializer
A Serializer implementation for Bebop

Enums

Error
The possible errors that the Bebop serializer and deserializer can return

Functions

from_bytes
Deserializes from raw bytes to the given type
to_bytes
Serializes the given object into a Bebop encoded vec of bytes
to_bytes_message
Forces serialization as a message. Normally, the serializer will automatically assume a Bebop message if there are optional fields and a Bebop struct if all the fields are required. This will force encoding as a message. Right now this will only force the top level struct to be a message, any embedded structs will not be assumed

Type Aliases

Result
A custom shorthand result type that always has an error type of Error